Module detector

Module detector 

Functions

artifact_dirs
Get the artifact directories for a project type
detect_project_type
Detect project type from a directory by checking for marker files
rebuild_hint
Get the rebuild command hint for a project type