pub struct DuplicateGroup {
pub hash: String,
pub size: u64,
pub files: Vec<DuplicateFile>,
pub is_clone_group: bool,
}Expand description
A group of duplicate files sharing the same content.
Fields
hash: Stringblake3 hash of the file content.
size: u64Size of each individual file in the group.
files: Vec<DuplicateFile>The duplicate files.
is_clone_group: boolTrue if all files in this group have the APFS clone flag set.
Implementations
Sourceimpl DuplicateGroup
impl DuplicateGroup
Sourcepub fn wasted_space(&self) -> u64
pub fn wasted_space(&self) -> u64
Total wasted space (all copies minus one).