Functions
- adjust_
risk - Elevate risk level if the path involves critical user data. This should be called on every CleanableItem before presenting to the user.
- is_
critical_ app_ path - Check if a path involves a critical app whose data should be Risk::High.
- is_
critical_ file - Check if a filename suggests critical user data.