Module sizing

Module sizing 

Structs

DirStats
Size and last-modified time computed in a single directory walk

Functions

dir_last_modified
Get the last modification time of any file in the directory
dir_size
Calculate the total size of a directory (sum of all file sizes)
dir_stats
Walk a directory once and return both total size and last-modified time.
format_size
Format bytes into human-readable string