pub fn dir_last_modified(path: &Path) -> Option<SystemTime>Expand description
Get the last modification time of any file in the directory
pub fn dir_last_modified(path: &Path) -> Option<SystemTime>Get the last modification time of any file in the directory